//
//  ClockController.swift
//  Lecture15_TimerAppBasicStudents
//
//  Created by Paul Crane on 17/09/18.
//  Copyright © 2018 Hamza. All rights reserved.
//

import Cocoa

class ClockView: NSView {
    
    private var handWidth:CGFloat = 10.0
    private var angleDegrees:Float = 0.0
    
    func updateAngle(degrees: Float){
        self.angleDegrees = degrees
    }
    
    override func draw(_ dirtyRect: NSRect) {
        super.draw(dirtyRect)
        let context = NSGraphicsContext.current!.cgContext
        
        context.saveGState()
        context.setFillColor(NSColor.black.cgColor)
        context.fillEllipse(in: dirtyRect)
        context.restoreGState()
        
        context.saveGState()
        context.setFillColor(NSColor.white.cgColor)
        
        context.translateBy(
            x: dirtyRect.width/2,
            y: dirtyRect.height/2)
        
        context.rotate(by: -CGFloat(angleDegrees) * CGFloat.pi/180)
        let rectangle = CGRect(x: -handWidth/2,
                               y: 0,
                               width: handWidth,
                               height: dirtyRect.height/2)
        
        context.addRect(rectangle)
        context.drawPath(using: .fill)
        
        context.fillEllipse(in: CGRect(
            x:-handWidth/2,
            y: -handWidth/2,
            width: handWidth,
            height: handWidth))
        
        context.restoreGState()
    }
    
}

class ClockController: NSWindowController, TimerModelDelegate {
    
    var timer: TimerModel? = nil
    static var windowCount: Int = 0;
    
    @IBOutlet var circleView: ClockView!
    @IBOutlet var outletStartStop: NSButton!
    @IBOutlet var outletReset: NSButton!
    
    func secondsChanged(_ second: Int) {
        circleView?.updateAngle(degrees: Float(second) / 60.0 * 360.0)
        circleView?.setNeedsDisplay(circleView.visibleRect)
    }
    
    convenience init(){
        self.init(windowNibName: NSNib.Name(rawValue: "ClockController"))
        
        //circleView = ClockView()
        
        timer = TimerModel()
        timer!.delegate = self
        timer!.reset()
    }
    
    override func windowDidLoad() {
        super.windowDidLoad()
        ClockController.windowCount += 1;
        window?.title = "Clock \(ClockController.windowCount)"
    }
    
    @IBAction func actionStartStop(_ sender: Any) {
        if (timer?.running)! {
            stopTimer()
        } else {
            startTimer()
        }
    }
    
    @IBAction func actionReset(_ sender: Any) {
        timer?.reset()
        circleView.updateAngle(degrees: 0)
    }
    
    func startTimer(){
        timer!.start();
        outletStartStop . title = " Stop ";
        outletReset . isEnabled = false ;
    }
    
    func stopTimer(){
        timer!.stop();
        outletReset . isEnabled = true ;
        outletStartStop?.title = " Start ";
    }
}
