//
//  TimerWindowController.swift
//  Lecture15_TimerAppBasicStudents
//
//  Created by Hamza on 13/09/18.
//  Copyright © 2018 Hamza. All rights reserved.
//

import Cocoa

class TimerWindowController: NSWindowController ,TimerModelDelegate {
    
    
    
    convenience init(){
        self.init(windowNibName: NSNib.Name(rawValue: "TimerWindowController"));
        timer = TimerModel();
        timer!.delegate = self;
        timer!.reset();
        
    }
    
    static var windowCount : Int = 0 ;
    
    // Outlet to the label that displays the formatted timer value
    @IBOutlet weak var outletLabel : NSTextField!
    
    // Outlets to the buttons at the bottom of the window
    @IBOutlet weak var outletReset : NSButton!
    @IBOutlet weak var outletStartStop : NSButton!
    

    
    var timer: TimerModel? = nil ;
    
    override func windowDidLoad() {
        super.windowDidLoad()

        // Implement this method to handle any initialization after your window controller's window has been loaded from its nib file.
        TimerWindowController.windowCount  += 1 ;
        window?.title = "Timer \(TimerWindowController.windowCount)" ;
    }
    
    
    
    
    // Toggle the state of the timer
    // (startTimer will create NSTimer if needed)
    @IBAction func actionStartStop (_ sender : Any) {
        if ( timer!.running == true ){
            stopTimer ();
        } else { // running == false !!
            startTimer ();
        }
    }
    // The reset action zeros the counter
    @IBAction func actionReset (_ sender : Any) {
        timer!.reset();
    }
    
    // Update the label to show the current time, formatted for display
    // callback target from TimerModel
    func secondsChanged(_ seconds: Int) {
        // Take the total number of seconds the timer has run for
        var secondsLocal = seconds ;
        // Determine how many hours and minutes this represents
        let hour = secondsLocal/3600;
        secondsLocal %= 3600;
        let min = secondsLocal/60;
        secondsLocal %= 60;
        // Update the label with the formatted timer value
        outletLabel?.stringValue = String (
            format :"%02ld:%02ld:%02ld",
            hour ,min , secondsLocal );
    }
    
    
    
    func startTimer(){
//         let del = NSApplication.shared.delegate as! AppDelegate;
        timer!.start();
        // Update the Start/Stop button label and menu and state of the reset button
        outletStartStop . title = " Stop ";
       // del.outletStartStopMenu?.title = " Stop ";
        outletReset . isEnabled = false ;
    }
    
    func stopTimer(){
        // let del = NSApplication.shared.delegate as! AppDelegate;
        timer!.stop();
        // Update the Start/Stop button label/Menu and state of the reset button
        outletReset . isEnabled = true ;
        outletStartStop?.title = " Start ";
        //del.outletStartStopMenu?.title = " Start ";
    }
    
    
    
    // When users interact with a menu, the system checks whether items should be greyed out.
    // We use our "running" state to determine whether to grey out start/Stop or Reset.
    override func validateMenuItem( _ menuItem: NSMenuItem) -> Bool {
         let del = NSApplication.shared.delegate as! AppDelegate;
        if ( menuItem == del.outletStartStopMenu){
            return !timer!.running;
        } else if (menuItem == del.outletResetMenu){
            return !timer!.running;
        } else if (menuItem == del.outletStopMenu){
            return timer!.running;
        }  else {
            return true;
        }
    }
    
    
}
